/**
 * @file    Api.h
 * @brief   ICWorkShop Safety License Shield Api Functions
 *
 * Safety License Shield
 * Copyright (c) 2009-2017, ICWorkshop Limited, All Rights Reserved
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
#ifndef __SISSDK_ECDSA_H
#define __SISSDK_ECDSA_H 		

#include <stdio.h>
#include <string.h>
#include <stdint.h>
#include <stdbool.h>

#include "mbedtls/config.h"
#include "mbedtls/platform.h"
#include "mbedtls/entropy.h"
#include "mbedtls/ctr_drbg.h"
#include "mbedtls/ecdsa.h"
#include "mbedtls/sha256.h"

#include "sissdk_benchmark.h"
#include "sissdk_utils.h"
#include "sissdk_crc.h"
#include "sissdk_aes.h"

#define SHA256_HASH_SIZE			32
#define CERTIFICATION_ID_SIZE       3
#define CERTIFICATION_PUB_SIZE      49
#define CERTIFICATION_PRI_SIZE      24
#define CERTIFICATION_SIG_MAX		MBEDTLS_ECDSA_MAX_LEN

#define ECDSA_RAND_FILL_SIGN_ENABLE	1		//enable /or disable rand fill sign

#pragma	pack(1) 
typedef struct S_ECDSA_SIGN
{
	uint16_t m_sign_size;					//real size
	uint8_t	 m_sign_data[CERTIFICATION_SIG_MAX];	//sign buffer
}S_ECDSA_SIGN;
#pragma pack()

#ifdef __cplusplus
extern "C" {
#endif

bool sissdk_ecdsa_verify(const uint8_t * pubKey,const uint8_t * src,uint32_t src_size,const	S_ECDSA_SIGN * sig);			//Verify a certificate
bool sissdk_ecdsa_sign(const uint8_t * priKey,const uint8_t * src,uint32_t src_size,S_ECDSA_SIGN * sig);				//Generate a certificate


#ifdef __cplusplus
}
#endif

#endif


