/**********************************************************************
 *
 * Filename:    sis_benchmark.c
 *
 * Description: Fast use sisapi_sdk
 *
 * Notes:       The parameters for each supported sisapi standard are
 *				defined in the header file aes.h.  The implementations
 *				here should stand up to further additions to that list.
 *
 *
 * Copyright (c) 2019 by ICWORKSHOP.  This software is placed into
 * the public domain and may be used for any purpose.  However, this
 * notice must not be changed or removed and no warranty is either
 * expressed or implied by its publication or distribution.
 **********************************************************************/

/**
 * @file    sis_benchmark.c
 * @brief   Implementation of sis_benchmark.h
 */
#include "sissdk_benchmark.h"
#include "sissdk_utils.h"
#include "sissdk_ecdsa.h"
#include "sissdk_aes.h"
#include "sissdk_crc.h"


#ifdef ENABLE_SIS_BENCHMARK


//public test data
const static uint8_t testdat[32] = {
																	0x52, 0x09, 0x6a, 0xd5, 0x30, 0x36, 0xa5, 0x38, 0xbf, 0x40, 0xa3, 0x9e, 0x81, 0xf3, 0xd7, 0xfb,
																	0x7c, 0xe3, 0x39, 0x82, 0x9b, 0x2f, 0xff, 0x87, 0x34, 0x8e, 0x43, 0x44, 0xc4, 0xde, 0xe9, 0xcb,
																	 };
#ifdef MBEDTLS_AES_C
//aes128cbc_test
static uint8_t output_1[32],output_2[32];
																	
//aes128cbc test key
const static uint8_t testKey[16] = { 0x96, 0xac, 0x74, 0x22, 0xe7, 0xad, 0x35, 0x85, 0xe2, 0xf9, 0x37, 0xe8, 0x1c, 0x75, 0xdf, 0x6e	};

//aes128cbc test iv
static uint8_t _testIv[16] = { 0x72, 0xf8, 0xf6, 0x64, 0x86, 0x68, 0x98, 0x16, 0xd4, 0xa4, 0x5c, 0xcc, 0x5d, 0x65, 0xb6, 0x92	};
const static uint8_t testIv[16] =  { 0x72, 0xf8, 0xf6, 0x64, 0x86, 0x68, 0x98, 0x16, 0xd4, 0xa4, 0x5c, 0xcc, 0x5d, 0x65, 0xb6, 0x92	};
#endif
//crc32
uint32_t m_crc32;

//test public key
const static uint8_t  		public_key[CERTIFICATION_PUB_SIZE]  = {
	0x04,0x85,0xEB,0xBE,0x6F,0xD3,0x90,0xF6,
	0x7F,0x5C,0x8A,0xFB,0xA5,0xDF,0x79,0x8D,
	0xEA,0x1E,0x4F,0x49,0x60,0x88,0x2A,0x02,
	0xB0,0x2C,0x53,0x7C,0x0C,0x12,0xB4,0x08,
	0xCF,0xAE,0x8F,0x94,0xE2,0x04,0xDE,0x4D,
	0xA7,0xA7,0x44,0x9A,0x52,0xA6,0xBD,0x1C,
	0x3E
};

//test cpuid
const static uint8_t  		cpuid_data[12]	 = {
	0x12,0x34,0x56,0x78,0x90,0xAB,0xCD,0xEF,
	0x13,0x24,0x57,0x68
};

//test private key (paired to test public key)
const static uint8_t  		private_key[CERTIFICATION_PRI_SIZE] = {
	0xF4,0xF0,0xB3,0x9F,0x89,0xC5,0x14,0xC0,
	0xC8,0x17,0xA3,0xDC,0xF7,0x4A,0x47,0x68,
	0x84,0xFE,0xF6,0x45,0x10,0x93,0x58,0xB3
};

static S_ECDSA_SIGN	sign_data;


/**
 * \brief  This function is used for testing purposes
 *
 * \return         none.
 */


void sis_benchmark(pfnGetSystemTick tickCallback)
{
	uint32_t uwTickStart,uwTickEnd;
	
	//for disable warning 
	uwTickEnd = 0;
	uwTickStart = uwTickEnd;
	uwTickEnd = uwTickStart;
	//-------------------------------Aes128 CBC test---------------------------------
#ifdef MBEDTLS_AES_C
	sis_log(LogDebug,"AES-CBC test\r\n");
	//encrypt
	memcpy(_testIv,testIv,sizeof(testIv));	//restore iv
	encrypt_buffer_cbc(testKey,_testIv,testdat,sizeof(testdat), output_1);
	//decrypt
	memcpy(_testIv,testIv,sizeof(testIv));	//restore iv
	decrypt_buffer_cbc(testKey,_testIv,output_1, sizeof(output_1), output_2);
	
	if(memcmp(testdat,output_2,sizeof(testdat)) != 0){
		sis_log(LogError,"AES-CBC Error\r\n");
	}else{
		sis_log(LogDebug,"AES-CBC test passed...\r\n");
	}
#endif	
	//Crc32
	sis_log(LogDebug,"Crc32 test\r\n");
	m_crc32 = crc32(testdat,sizeof(testdat));
	sis_log(LogDebug,"Crc32:0x%08x\r\n",m_crc32);
	
	//sign
	uwTickStart = tickCallback?tickCallback():0;
	if(sissdk_ecdsa_sign(private_key,cpuid_data,sizeof(cpuid_data),&sign_data)){
		sis_log(LogDebug,"Sign ok...\r\n");
	}
	else{
		sis_log(LogDebug,"Sign Error...\r\n");
	}
	uwTickEnd = tickCallback?tickCallback():0;
	sis_log(LogDebug,"---------------Elapsed time : %d ms ---------------\r\n",uwTickEnd - uwTickStart);
	
	//verfiy sign
	uwTickStart = tickCallback?tickCallback():0;
	if(sissdk_ecdsa_verify(public_key,cpuid_data,sizeof(cpuid_data),&sign_data)){
		sis_log(LogDebug,"verify passed...\r\n");
	}
	else{
		sis_log(LogDebug,"verify error...\r\n");
	}
	uwTickEnd = tickCallback?tickCallback():0;
	sis_log(LogDebug,"---------------Elapsed time : %d ms ---------------\r\n",uwTickEnd - uwTickStart);
}

#endif


